.. _bluegraph_backends_graph_tool_ref:

`graph_tool` package
--------------------

Reference page for the `bluegraph.backends.graph_tool` package. All the interfaces below are also available as `bluegraph.backends.graph_tool.<interface>` (for example, :code:`from bluegraph.backends.graph_tool import GTPathFinder`).


Graph metrics
^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.graph_tool.analyse.metrics
	:members:


Path search
^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.graph_tool.analyse.paths
	:members:


Community Detection
^^^^^^^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.graph_tool.analyse.communities
	:members: